@@ -1,9 +1,13 @@
 import unittest
 import logging
 import sys
+import os
 from contextlib import contextmanager
 from yozuch import logger
 from yozuch.ttt import StringIO
+from yozuch.config import Config
+
+ROOT_DIR = os.path.dirname(__file__)
 
 
 class MockLoggingHandler(logging.Handler):
@@ -32,6 +36,8 @@ class YozuchTestCase(unittest.TestCase):
         self._orig_handlers = logger.handlers
         logger.handlers = []
         logger.addHandler(self.logger_handler)
+        self.config = Config()
+        self.config.update_from_directory(os.path.join(ROOT_DIR, 'data'))
 
     def tearDown(self):
         logger.handlers = self._orig_handlers
