@@ -1,8 +1,6 @@
-from yozuch.generators import content_generator
 from yozuch.generators.post_item_collection import PostItemCollectionGenerator
 
 
-@content_generator('categories')
 class CategoryGenerator(PostItemCollectionGenerator):
 
     def __init__(self):
